def father():
    print("my father is biju")
def mother():
    print("my mther is anitha")
def sister():
    print("my sister is chandralekha")
def pet():
    print("my pet is monkuttan")
def housename():
    print("sivasailam")
def plcae():
    print("keralapuram, kollam, kerala")
def personalno():
    print("8089156390")


import setuptools
from pathlib import Path
setuptools.setup(
    name = "sivadathhistory",
    version = 1.0,
    long_description = Path("README.md").read_text(),
    packages = setuptools.setuptools.find_packages(exclude = ["data", "tests"])
)